@@ -4,7 +4,7 @@
 ----
 
 """
-import time
+from Fishconsole import houtai
 
 try:
     import re
@@ -38,8 +38,19 @@ from Fishconsole import houtai
 # 导入强制更新系统所需要的内容
 
 
+def list去重(数据源):
+    """
+    Fishconsole list去重
+    就是一个去重复值的
 
+    :return:
+    """
+    去重完成 = []
+    for i in 数据源:
+        if i not in 去重完成:
+            去重完成.append(i)
 
+    return 去重完成
 
 
 
@@ -88,6 +99,7 @@ def 官网存活性检测(官网地址: str = "http://www.baidu.com", 测试时
 
     - 就是判断官网能不能链接，可以用来检测联网，能联返回ture，不能返回False
 
+    :param 测试时长:
     :param 官网地址: 官网地址
     :return: 布尔值
     """
@@ -140,7 +152,7 @@ def Fishconsole_Update():
 
     UPI = files.缓存(2, 变量名="UPI")
     if UPI == "error":
-        UPI = False
+
         temp = files.缓存(2)
         temp["UPI"] = False
         files.缓存(1, temp)
@@ -211,14 +223,9 @@ def Fishconsole_Update():
                 config["year"] = 2005
                 config["month"] = 6
                 config["day"] = 11
-                上一年 = config.get("year")
-                上一月 = config.get("month")
-                上一日 = config.get("day")
                 files.缓存(1, config)
             else:
-                上一年 = config.get("year")
-                上一月 = config.get("month")
-                上一日 = config.get("day")
+                pass
 
             if updata is None:
                 系统日志("updata配置不存在，创建", "强制更新系统", UPI)
@@ -1210,7 +1217,7 @@ def 数字字母化(模式, 数据源):
             数据源 = list(str(数据源))
             计数器 = 0
             计数器a = 0
-            for a in 数据源:
+            for _ in 数据源:
                 计数器a = 计数器a + 1
             for a in 数据源:
                 if a == "A":
@@ -1289,7 +1296,7 @@ def 任务平均分配(任务数量, 数据源: list):
                 空列表 = []
                 计数器a = 0
         for a in 完成列表:
-            for b in a:
+            for _ in a:
                 计数器c = 计数器c + 1
         for _ in 完成列表:
             计数器d = 计数器d + 1
