@@ -17,7 +17,7 @@ def version():
 
     :return: 返回版本号
     """
-    return '3.0.4'
+    return '3.0.6'
 
 
 def f_debug():
@@ -328,7 +328,6 @@ def f_debug():
 
                 if a in ["AC", "ac"]:
                     未选触发器 = False
-                    计数器 = 0
                     try:
                         smtp授权码 = b[2]
                     except:
@@ -393,6 +392,8 @@ def f_debug():
 
             helps_res = threading.Thread(target=帮助)
             helps_res.start()
+
+
         elif b[0] in ["updata", "UPDATA"]:
             print(logs.日志("Fcv_debug Console》我们将尝试激活更新，在程序执行完毕以后，我们将阻止强制更新系统在下一次继续运行", "蓝色"))
             files.缓存(3, 数据={'updata': True})
@@ -407,6 +408,7 @@ def f_debug():
             time.sleep(3)
             threading.Thread(target=temp).start()
 
+
         elif b[0] in ["execute"]:
             未选触发器 = True
             空容器 = ""
@@ -424,5 +426,46 @@ def f_debug():
                 print("他的作用就是调用系统默认的终端来执行指定的内容")
                 print("语法就是 execute + 系统指令")
 
+
+        elif b[0] in ["turn", "turn"]:
+            未选触发器 = True
+            for a in b:
+                # 循环检测
+
+                if a in ['file_protect','FILE_PROTECT']:
+                    for a in b:
+                        if a in ['on','ON']:
+                            print('turn on file_protect')
+                            未选触发器 = False
+                            break
+                        elif a in ['off','OFF']:
+                            print('turn off file_protect')
+                            未选触发器 = False
+                            break
+
+                if a in ['file_protect','FILE_PROTECT','文件保护']:
+                    for a in b:
+                        if a in ['on','ON']:
+                            print('turn on file_protect')
+                            未选触发器 = False
+                            break
+                        elif a in ['random_ip','RANDOM_IP','随机ip','随机IP']:
+                            print('turn off file_protect')
+                            未选触发器 = False
+                            break
+
+            if 未选触发器:
+                print(logs.分割线(f"这是turn的简介", "fcv_debug console", 色选="红色"))
+                print("他的作用就是对后台的程序进行管理，这样就可以做到控制后台")
+                print("可用后台：")
+                print("文件保护系统\n随机ip池")
+                print('------------------')
+                print('可用模式有：')
+                print('on（启动）')
+                print('off （关闭）')
+                print('------------------')
+                print('语法是：turn+关键字on/off+关键字可用后台')
+                print("如果想了解具体的用法，请在终端中键入'help'或者'?'")
+
         else:
             print(logs.日志(f"‘{b[0]}’是不受支持的命令，如果想查看命令，请键入'help'或者'?'", 色选="红色"))
