@@ -7,19 +7,15 @@
 
 """
 
-import os
 import sys
-from Fishconsole import fcv#激活强制更新要用
-# 显示行列要用
-import signal
 
-#显示编码要用
+# 显示编码要用
 import chardet
 
+from Fishconsole import fcv  # 激活强制更新要用
 
 
-
-
+# 显示行列要用
 
 
 def 颜色(text, 色选="None"):
@@ -138,7 +134,7 @@ def 分割线(标题, text, 色选="Nona"):
 
 
 
-def 变量查看(变量名: str, 变量, 色选: str = "红色",自动换行=False):
+def 变量查看(变量名: str, 变量, 色选: str = "红色"):
     """
     FishCosnole LOGS 变量查看模块
 
